/**
 * En ansatt fr betaling per time vedkommende har arbeidet i innevrende uke,
 * ut fra en fast sats for hver time. For hver time arbeidet utover en normert
 * arbeidsuke, betales dobbel sats per time.
 */
class AnsattV0 {
  // Statisk variabel
  final static double NORMAL_ARBEIDSUKE = 37.5;

  // Feltvariabler
  String fornavn;
  String etternavn;
  double timelnn;

  // Konstruktrer
  /**
   * Oppretter en ansatt med standardverdier for navn og timelnn.
   */
  AnsattV0() { // eksplisitt standardkonstruktr
    // Lar alle feltvariabler f standardverdier
  }

  /**
   * Oppretter en ansatt med gitt navn og timelnn.
   *
   * @param fornavn
   *          Fornavnet (og eventuelle mellomnavn) til den ansatte.
   * @param etternavn
   *          Etternavnet til den ansatte.
   * @param timelnn
   *          Betaling per time i kroner og re.
   */
  AnsattV0(String fornavn, String etternavn, double timelnn) {
    this.fornavn = fornavn;
    this.etternavn = etternavn;
    this.timelnn = timelnn;
  }

  // Instansmetoder
  /**
   * Beregner ukelnnen for den ansatte.
   *
   * @param antallTimer
   *          Antallet arbeidstimer (>0) i innevrende uke.
   * @return Ukelnnen i kroner og re for innevrende uke.
   */
  double beregnUkelnn(double antallTimer) {
    double fastUkelnn = timelnn * NORMAL_ARBEIDSUKE;
    if (antallTimer <= NORMAL_ARBEIDSUKE)
      return fastUkelnn;
    else
      return fastUkelnn + 2.0 * timelnn * beregnOvertid(antallTimer);
  }

  /**
   * Skriver ut navn og timelnn for den ansatte.
   */
  void skrivTilstand() {
    System.out.printf("Ansatt %s %s har timelnn %.2f kroner%n", fornavn,
        etternavn, timelnn);
  }

  // Statiske metoder
  /**
   * Beregner antall timer overtid en ansatt har arbeidet denne uken.
   *
   * @param antallTimer
   *          Totalt antall timer (>= NORMAL_ARBEIDSUKE) en ansatt har arbeidet.
   * @return Antallet overtidstimer.
   */
  static double beregnOvertid(double antallTimer) {
    return (antallTimer - NORMAL_ARBEIDSUKE);
  }
}