/**
 * En arbeidsleder fr betaling per time vedkommende har arbeidet i innevrende
 * uke, pluss et fast ledertillegg.
 */
class ArbeidsLederV0 extends AnsattV0 {
  // Feltvariabel
  double lederTillegg;

  // Konstruktrer
  /**
   * Oppretter en arbeidsleder med standardverdier for alle felter.
   */
  ArbeidsLederV0() { // eksplisitt standardkonstruktr
    super(); // (1)
  }

  /**
   * Oppretter en arbeidsleder med gitt navn og timelnn. Ledertillegg blir satt
   * til standardverdi (0,0).
   *
   * @param fornavn
   *          Fornavnet (og eventuelle mellomnavn) til arbeideren.
   * @param etternavn
   *          Etternavnet til arbeideren.
   * @param timelnn
   *          Betaling per time i kroner og re.
   */
  ArbeidsLederV0(String fornavn, String etternavn, double timelnn) {
    super(fornavn, etternavn, timelnn); // (2)
  }

  /**
   * Oppretter en arbeidsleder med gitt navn, timelnn og ledertillegg.
   *
   * @param fornavn
   *          Fornavnet (og eventuelle mellomnavn) til arbeideren.
   * @param etternavn
   *          Etternavnet til arbeideren.
   * @param timelnn
   *          Betaling per time i kroner og re.
   * @param tillegg
   *          Ledertillegget som adderes til ukelnnen.
   */
  ArbeidsLederV0(String fornavn, String etternavn, double timelnn,
      double tillegg) {
    super(fornavn, etternavn, timelnn); // (3)
    lederTillegg = tillegg; // lagrer utvidet tilstand
  }

  // Instansmetoder
  /**
   * Beregner ukelnnen for arbeidslederen.
   *
   * @param antallTimer
   *          Antallet arbeidstimer (>0) i innevrende uke.
   * @return Ukelnnen i kroner og re for innevrende uke.
   */
  double beregnLederlnn(double antallTimer) { // (4)
    double fastUkelnn = super.beregnUkelnn(antallTimer); // (5)
    fastUkelnn += lederTillegg; // (6)
    return fastUkelnn;
  }

  /**
   * Skriver ut navn, timelnn og tillegg for arbeidslederen.
   */
  @Override
  void skrivTilstand() { // (7)
    super.skrivTilstand();
    System.out.printf("Ledertillegg: %.2f kroner%n", lederTillegg);
  }
}